Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(90)

Unified Diff: components/webdata/common/web_database_service.h

Issue 962903003: Rename WebDataServiceBackend to WebDatabaseBackend (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: rebase and fix nits Created 5 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: components/webdata/common/web_database_service.h
diff --git a/components/webdata/common/web_database_service.h b/components/webdata/common/web_database_service.h
index 3c766573d061b127351065c18b14a1461a304c8e..dffbfa14978df566f66b92ec4215f7e7a7a8b94c 100644
--- a/components/webdata/common/web_database_service.h
+++ b/components/webdata/common/web_database_service.h
@@ -23,7 +23,7 @@
#include "components/webdata/common/web_database.h"
#include "components/webdata/common/webdata_export.h"
-class WebDataServiceBackend;
+class WebDatabaseBackend;
class WebDataRequestManager;
namespace content {
@@ -77,8 +77,8 @@ class WEBDATA_EXPORT WebDatabaseService
// TODO(caitkp): remove this method once SyncServices no longer depend on it.
virtual WebDatabase* GetDatabaseOnDB() const;
- // Returns a pointer to the WebDataServiceBackend.
- scoped_refptr<WebDataServiceBackend> GetBackend() const;
+ // Returns a pointer to the WebDatabaseBackend.
+ scoped_refptr<WebDatabaseBackend> GetBackend() const;
// Schedule an update/write task on the DB thread.
virtual void ScheduleDBTask(
@@ -129,7 +129,7 @@ class WEBDATA_EXPORT WebDatabaseService
// The primary owner is |WebDatabaseService| but is refcounted because
// PostTask on DB thread may outlive us.
- scoped_refptr<WebDataServiceBackend> wds_backend_;
+ scoped_refptr<WebDatabaseBackend> web_db_backend_;
// Callbacks to be called once the DB has loaded.
LoadedCallbacks loaded_callbacks_;
« no previous file with comments | « components/webdata/common/web_database_backend.cc ('k') | components/webdata/common/web_database_service.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698